@@ -22,7 +22,7 @@ class TonAbi(TonModule):
         """
         Decodes message body using provided body BOC and ABI
         :param abi: Contract ABI used to decode
-        :param body: Base64 encoded message body BOC
+        :param body: Message body BOC encoded in `base64`
         :param is_internal: True if the body belongs to the internal message
         :return:
         """
@@ -38,8 +38,8 @@ class TonAbi(TonModule):
         Creates account state BOC
         :param state_init: Source of the account state init
         :param balance: Initial balance
-        :param last_trans_lt: Initial value for the 'last_trans_lt'
-        :param last_paid: Initial value for the 'last_paid'
+        :param last_trans_lt: Initial value for the `last_trans_lt`
+        :param last_paid: Initial value for the `last_paid`
         :return:
         """
         return self.request(
@@ -51,28 +51,52 @@ class TonAbi(TonModule):
             deploy_set: DeploySet = None, call_set: CallSet = None,
             processing_try_index: int = 0) -> Dict[str, str]:
         """
-        Encodes an ABI-compatible message
+        Encodes an ABI-compatible message.
+        Allows to encode deploy and function call messages, both signed and
+        unsigned.
+        Use cases include messages of any possible type:
+            - deploy with initial function call (i.e. `constructor` or any
+              other function that is used for some kind of initialization);
+            - deploy without initial function call;
+            - signed/unsigned + data for signing.
+
+        `Signer` defines how the message should or shouldn't be signed:
+            - `Signer::None` creates an unsigned message. This may be needed
+               in case of some public methods, that do not require
+               authorization by pubkey;
+            - `Signer::External` takes public key and returns `data_to_sign`
+               for later signing.
+               Use `attach_signature` method with the result signature to get
+               the signed message;
+            - `Signer::Keys` creates a signed message with provided key pair;
+            - [SOON] `Signer::SigningBox` Allows using a special interface to
+              implement signing without private key disclosure to SDK.
+              For instance, in case of using a cold wallet or HSM, when
+              application calls some API to sign data.
         :param abi: Contract ABI
-        :param address: Contract address. Must be specified in case of
-                non deploy message
+        :param address: Target address the message will be sent to. Must be
+                specified in case of non-deploy message
         :param deploy_set: Deploy parameters. Must be specified in case of
                 deploy message
-        :param call_set: Function call parameters. Must be specified in
-                non deploy message. In case of deploy message contains
-                parameters of constructor
+        :param call_set: Function call parameters. Must be specified in case
+                of non-deploy message. In case of deploy message it is optional
+                and contains parameters of the functions that will to be
+                called upon deploy transaction
         :param signer: Signing parameters
         :param processing_try_index: Processing try index. Used in message
-                processing with retries. Encoder uses the provided try index
-                to calculate message expiration time. Expiration timeouts will
-                grow with every retry
+                processing with retries (if contract's ABI includes "expire"
+                header). Encoder uses the provided try index to calculate
+                message expiration time. The 1st message expiration time is
+                specified in client config. Expiration timeouts will grow with
+                every retry
         :return:
         """
         deploy_set = deploy_set.dict if deploy_set else deploy_set
         call_set = call_set.dict if call_set else call_set
         return self.request(
-            method='abi.encode_message', abi=abi.dict,
-            address=address, deploy_set=deploy_set, call_set=call_set,
-            signer=signer.dict, processing_try_index=processing_try_index)
+            method='abi.encode_message', abi=abi.dict, address=address,
+            deploy_set=deploy_set, call_set=call_set, signer=signer.dict,
+            processing_try_index=processing_try_index)
 
     def encode_message_body(
             self, abi: Abi, call_set: CallSet, signer: Signer,
@@ -81,9 +105,9 @@ class TonAbi(TonModule):
         """
         Encodes message body according to ABI function call
         :param abi: Contract ABI
-        :param call_set: Function call parameters. Must be specified in
-                non deploy message. In case of deploy message contains
-                parameters of constructor
+        :param call_set: Function call parameters. Must be specified in non
+                deploy message. In case of deploy message contains parameters
+                of constructor
         :param signer: Signing parameters
         :param is_internal: True if internal message body must be encoded
         :param processing_try_index: Processing try index. Used in message
@@ -101,25 +125,26 @@ class TonAbi(TonModule):
             self, abi: Abi, public_key: str, message: str, signature: str
     ) -> Dict[str, str]:
         """
-        Combines hex-encoded signature with base64-encoded unsigned message
+        Combines `hex`-encoded `signature` with `base64`-encoded
+        `unsigned_message`
         :param abi: Contract ABI
-        :param public_key: Hex encoded public key
-        :param message: Base64 encoded unsigned message BOC
-        :param signature: Hex encoded signature
+        :param public_key: Public key encoded in `hex`
+        :param message: Unsigned message BOC encoded in `base64`
+        :param signature: Signature encoded in `hex`
         :return:
         """
         return self.request(
-            method='abi.attach_signature', abi=abi.dict,
-            public_key=public_key, message=message, signature=signature)
+            method='abi.attach_signature', abi=abi.dict, public_key=public_key,
+            message=message, signature=signature)
 
     def attach_signature_to_message_body(
             self, abi: Abi, public_key: str, message: str, signature: str
     ) -> Dict[str, str]:
         """
         :param abi: Contract ABI
-        :param public_key: Hex encoded public key
-        :param message: Base64 encoded unsigned message BOC
-        :param signature: Hex encoded signature
+        :param public_key: Public key encoded in `hex`
+        :param message: Unsigned message BOC encoded in `base64`
+        :param signature: Signature encoded in `hex`
         :return:
         """
         return self.request(
