@@ -16,17 +16,20 @@ class TonProcessing(TonModule):
         Creates message, sends it to the network and monitors its processing
         :param abi: Contract ABI
         :param signer: Signing parameters
-        :param address: Contract address. Must be specified in case of
-                non deploy message
+        :param address: Target address the message will be sent to. Must be
+                specified in case of non-deploy message
         :param deploy_set: Deploy parameters. Must be specified in case of
                 deploy message
-        :param call_set: Function call parameters. Must be specified in
-                non deploy message. In case of deploy message contains
-                parameters of constructor
+        :param call_set: Function call parameters. Must be specified in case
+                of non-deploy message. In case of deploy message it is optional
+                and contains parameters of the functions that will to be
+                called upon deploy transaction
         :param processing_try_index: Processing try index. Used in message
-                processing with retries. Encoder uses the provided try index
-                to calculate message expiration time. Expiration timeouts will
-                grow with every retry
+                processing with retries (if contract's ABI includes "expire"
+                header). Encoder uses the provided try index to calculate
+                message expiration time. The 1st message expiration time is
+                specified in client config. Expiration timeouts will grow with
+                every retry
         :param send_events: Flag for requesting events sending
         :return:
         """
@@ -35,8 +38,7 @@ class TonProcessing(TonModule):
             call_set=call_set, processing_try_index=processing_try_index)
         return self.request(
             method='processing.process_message', as_iterable=send_events,
-            message_encode_params=message_source.dict,
-            send_events=send_events)
+            message_encode_params=message_source.dict, send_events=send_events)
 
     @Response.send_message
     def send_message(
@@ -44,7 +46,7 @@ class TonProcessing(TonModule):
     ) -> Union[str, Generator]:
         """
         Sends message to the network
-        :param message: Message BOC
+        :param message: Message BOC. Encoded with `base64`
         :param send_events: Flag for requesting events sending
         :param abi: Optional message ABI. If this parameter is specified and
                 the message has the 'expire' header then expiration time will
@@ -66,14 +68,15 @@ class TonProcessing(TonModule):
             abi: Abi = None) -> Union[Dict[str, Any], Generator]:
         """
         Performs monitoring of the network for the result transaction
-        :param message: Base64 encoded message BOC
-        :param shard_block_id: Dst account shard block id before the message
-                had been sent. You must provide the same value as the
-                'send_message' has returned
+        :param message: Message BOC. Encoded with `base64`
+        :param shard_block_id: The last generated block id of the destination
+                account shard before the message was sent. You must provide
+                the same value as the `send_message` has returned
         :param send_events: Flag for requesting events sending
         :param abi: Optional ABI for decoding transaction results. If it is
                 specified then the output messages bodies will be decoded
-                according to this ABI.
+                according to this ABI. The `abi_decoded` result field will be
+                filled out
         :return:
         """
         abi = abi.dict if abi else abi
